@@ -1,7 +1,7 @@
 """Abstract hardware backend implementation provided by j5 for serial comms."""
 from abc import abstractmethod
 from datetime import timedelta
-from typing import Optional, Set, Type
+from typing import Optional, Set, Type, cast
 
 from serial import Serial, SerialException, SerialTimeoutException
 from typing_extensions import Protocol
@@ -38,6 +38,16 @@ class Seriallike(Protocol):
         """Read a line from the serial port."""
         ...  # pragma: nocover
 
+    @property
+    @abstractmethod
+    def in_waiting(self) -> int:
+        """Return the number of characters currently in the input buffer."""
+        ...  # pragma: nocover
+
+    def read(self, size: int = 1) -> bytes:
+        """Read size bytes from the serial port."""
+        ...  # pragma: nocover
+
     def write(self, data: bytes) -> int:
         """Write data to the serial port."""
         ...  # pragma: nocover
@@ -51,7 +61,8 @@ class SerialHardwareBackend(Backend, metaclass=BackendMeta):
     def __init__(
             self,
             serial_port: str,
-            serial_class: Type[Seriallike] = Serial,
+            *,
+            serial_class: Type[Seriallike] = cast(Type[Seriallike], Serial),  # noqa: B008
             baud: int = 115200,
             timeout: timedelta = DEFAULT_TIMEOUT,
     ) -> None:
@@ -98,3 +109,24 @@ class SerialHardwareBackend(Backend, metaclass=BackendMeta):
 
         ldata = bdata.decode('utf-8')
         return ldata.rstrip()
+
+    def read_serial_chars(self, size: int = 1) -> str:
+        """Read size bytes from the serial interface."""
+        if size > self._serial.in_waiting:
+            raise ValueError(f"Tried to read {size} bytes from the serial buffer, "
+                             f"only {self._serial.in_waiting} were available.")
+
+        try:
+            bdata = self._serial.read(size)
+        except SerialTimeoutException as e:
+            raise CommunicationError(f"Serial Timeout Error: {e}") from e
+        except SerialException as e:
+            raise CommunicationError(f"Serial Error: {e}") from e
+
+        if len(bdata) != size:
+            raise CommunicationError(
+                f"Expected to receive {size} chars, got {len(bdata)} instead.",
+            )
+
+        ldata = bdata.decode('utf-8')
+        return ldata.rstrip()
